@@ -304,7 +304,7 @@ _register_playbin_actions (void)
 /* *INDENT-ON* */
 }
 
-int main (int argc, gchar ** argv);
+static int real_main (int argc, gchar ** argv);
 
 static int
 run_test_from_file (gchar * testfile, gboolean use_fakesinks)
@@ -325,7 +325,7 @@ run_test_from_file (gchar * testfile, gboolean use_fakesinks)
   argv[0] = (gchar *) "gst-validate-" GST_API_VERSION;
   memcpy (&argv[1], args, sizeof (char *) * (argc));
 
-  ret = main (argc, argv);
+  ret = real_main (argc, argv);
 
   g_strfreev (args);
   g_free (argv);
@@ -333,8 +333,8 @@ run_test_from_file (gchar * testfile, gboolean use_fakesinks)
   return ret;
 }
 
-int
-main (int argc, gchar ** argv)
+static int
+real_main (int argc, gchar ** argv)
 {
   GError *err = NULL;
   gchar *scenario = NULL, *configs = NULL, *media_info = NULL,
@@ -634,3 +634,25 @@ exit:
   gst_deinit ();
   return ret;
 }
+
+int
+main (int argc, char *argv[])
+{
+  int ret;
+
+#ifdef G_OS_WIN32
+  argv = g_win32_get_command_line ();
+#endif
+
+#if defined(__APPLE__) && TARGET_OS_MAC && !TARGET_OS_IPHONE
+  ret = gst_macos_main ((GstMainFunc) real_main, argc, argv, NULL);
+#else
+  ret = real_main (argc, argv);
+#endif
+
+#ifdef G_OS_WIN32
+  g_strfreev (argv);
+#endif
+
+  return ret;
+}
